@@ -6,10 +6,10 @@ class FFile:
 	nomeFile: str
 	"""Nome del file da leggere"""
 
-	_json: dict
+	json_: dict
 	"""Contenuto del file decodificato in JSON"""
 
-	_string: str
+	string_: str
 	"""Contenuto del file in Stringa"""
 
 	def __init__(self, nomeFile) -> None:
@@ -26,7 +26,7 @@ class FFile:
 		"""Legge il file"""
 		if self.__file_exists():
 			with open(self.nomeFile, 'r') as fr:
-				self._string = fr.read()
+				self.string_ = fr.read()
 		else:
 			print("File not exists")
 
@@ -34,7 +34,7 @@ class FFile:
 		"""Legge il JSON e lo decodifica"""
 		if self.__file_exists():
 			self.read_file()
-			self._json = json.loads(self._string)
+			self.json_ = json.loads(self.string_)
 		else:
 			print("File not exists")
 
